Package: intamap
Version: 1.5-7
Date: 2023-10-30
Title: Procedures for Automated Interpolation
Authors@R: c(person("Edzer", "Pebesma", role = c("aut"), email = "edzer.pebesma@uni-muenster.de"),
           person("Jon Olav", "Skoien", role = c("aut", "cre"), email = "jon.skoien@gmail.com"),
           person("Olivier", "Baume", role = c("ctb")),
           person("A", "Chorti", role = "ctb"), 
           person("Dionisis", "Hristopulos", role = "ctb"), 
           person("Hannes", "Kazianka", role = "ctb"), 
           person("Stepahnie", "Melles", role = "ctb"),
           person("Giannis", "Spiliopoulos", role = "ctb"))
Maintainer: Jon Olav Skoien <jon.skoien@gmail.com>
Depends: R (>= 2.14.0), sp (>= 0.9-0)
Imports: gstat (>= 0.9-36), sf, automap, MBA, mvtnorm, MASS, evd,
        doParallel, foreach, parallel, stats, methods, grDevices,
        utils, graphics
Suggests: psgp
Description: Geostatistical interpolation has traditionally been done by manually fitting a variogram and then interpolating. Here, we introduce classes and methods that can do this interpolation automatically. Pebesma et al (2010) gives an overview of the methods behind and possible usage <doi:10.1016/j.cageo.2010.03.019>.
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2023-10-30 10:34:22 UTC; skoiejo
Author: Edzer Pebesma [aut],
  Jon Olav Skoien [aut, cre],
  Olivier Baume [ctb],
  A Chorti [ctb],
  Dionisis Hristopulos [ctb],
  Hannes Kazianka [ctb],
  Stepahnie Melles [ctb],
  Giannis Spiliopoulos [ctb]
Repository: CRAN
Date/Publication: 2023-10-30 11:40:06 UTC
Built: R 4.4.0; ; 2024-04-30 10:08:48 UTC; unix
